from .discipline_filtered_viewset import DisciplineFilteredViewSet
from .discipline_viewset import DisciplineViewSet
from .document_by_id_viewset import DocumentByIdViewSet
from .document_viewset import DocumentViewSet
from .group_viewset import GroupViewSet
from .training_set_viewset import TrainingSetViewSet
from .training_set_by_id_viewset import TrainingSetByIdViewSet
from .other_viewset import public_upload, redirect_view
from .word_viewset import WordViewSet

__all__ = [
    "DisciplineFilteredViewSet",
    "DisciplineViewSet",
    "DocumentByIdViewSet",
    "DocumentViewSet",
    "GroupViewSet",
    "TrainingSetViewSet",
    "TrainingSetByIdViewSet",
    "public_upload",
    "redirect_view",
]
