from .discipline_admin import DisciplineAdmin
from .training_set_admin import TrainingSetAdmin
from .document_admin import DocumentAdmin
from .group_api_key_admin import GroupAPIKeyAdmin

__all__ = ["DisciplineAdmin", "TrainingSetAdmin", "DocumentAdmin", "GroupAPIKeyAdmin"]
